#!/usr/bin/env python3

from setuptools import setup, find_packages
import distutils


class TranslateCommand(distutils.cmd.Command):
    description = "Translation"

    user_options = []
    sub_commands = [
        ('extract_messages', None),
        ('update_catalog', None),
        ('compile_catalog', None),
    ]

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        for cmd_name in self.get_sub_commands():
            self.run_command(cmd_name)


with open("README.rst", "r") as fh:
    long_description = fh.read()


setup(
    name='sphinx_storymaker',
    version='0.1.0',
    url="https://procrastinator.nerv-project.eu/nerv-project/sphinx_storymaker",
    license="EUPL 1.2",
    author="Kujiu",
    author_email="kujiu-pypi@kujiu.org",
    descrption="Make your book and visual novel with Sphinx and Escoria",
    keywords="novel sphinx escoria",
    long_description=long_description,
    long_description_content_type="text/x-rst",
    packages=["sphinx_storymaker"],
    cmdclass={
        'translate': TranslateCommand,
    },
    package_data={
        "sphinx_storymaker": [
            "locale/*/LC_MESSAGES/*.mo",
            "locale/*/LC_MESSAGES/*.po",
        ]
    },
    entry_points={
        'sphinx.builders': [
            'escoria = sphinx_storymaker.escoria_builder.EscoriaBuilder',
        ]
    },
    install_requires=[
        "Sphinx>=3.0.0",
        "sphinxcontrib-blockdiag"
    ],
    license_files=["LICENSE", "LICENSE-de", "LICENSE-fr", "LICENSE-nl"],
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Environment :: Console :: Curses",
        "Environment :: X11 Applications :: Qt",
        "Framework :: Sphinx :: Extension",
        "License :: OSI Approved :: European Union Public Licence 1.2 (EUPL 1.2)",
        "Programming Language :: Python :: 3",
        "Topic :: Artistic Software",
        "Topic :: Games/Entertainment :: Role-Playing",
    ],
    project_urls={
        "Source": "https://procrastinator.nerv-project.eu/nerv-project/sphinx_storymaker",
        "Issues": "https://procrastinator.nerv-project.eu/nerv-project/sphinx_storymaker/issues",
    },
)
